@@ -31,6 +31,7 @@ enum {
 	RIGHT_CLICK,
 	CLICK,
 	KEY_PRESS,
+	START_DRAG,
 	LAST_SIGNAL
 };
 
@@ -381,13 +382,19 @@ e_table_group_compute_location (ETableGroup *etg, int *x, int *y, int *row, int
  * removed from the value row points to.
  */
 void
-e_table_group_get_position (ETableGroup *etg, int *x, int *y, int *row, int *col)
+e_table_group_get_cell_geometry  (ETableGroup *etg,
+				  int         *row,
+				  int         *col,
+				  int         *x,
+				  int         *y,
+				  int         *width,
+				  int         *height)
 {
 	g_return_if_fail (etg != NULL);
 	g_return_if_fail (E_IS_TABLE_GROUP (etg));
 
-	if (ETG_CLASS (etg)->get_position)
-		ETG_CLASS (etg)->get_position (etg, x, y, row, col);
+	if (ETG_CLASS (etg)->get_cell_geometry)
+		ETG_CLASS (etg)->get_cell_geometry (etg, row, col, x, y, width, height);
 }
 
 /** 
@@ -518,6 +525,30 @@ e_table_group_key_press (ETableGroup *e_table_group, gint row, gint col, GdkEven
 	return return_val;
 }
 
+/** 
+ * e_table_group_start_drag
+ * @eti: %ETableGroup to emit the signal on
+ * @row: The cursor row (model row)
+ * @col: The cursor col (model col)
+ * @event: The event that caused this signal
+ *
+ * This routine emits the "start_drag" signal.
+ */
+gint
+e_table_group_start_drag (ETableGroup *e_table_group, gint row, gint col, GdkEvent *event)
+{
+	gint return_val = 0;
+
+	g_return_val_if_fail (e_table_group != NULL, 0);
+	g_return_val_if_fail (E_IS_TABLE_GROUP (e_table_group), 0);
+
+	gtk_signal_emit (GTK_OBJECT (e_table_group),
+			 etg_signals [START_DRAG],
+			 row, col, event, &return_val);
+
+	return return_val;
+}
+
 /** 
  * e_table_group_get_header
  * @eti: %ETableGroup to check
@@ -580,6 +611,7 @@ etg_class_init (GtkObjectClass *object_class)
 	klass->right_click = NULL;
 	klass->click = NULL;
 	klass->key_press = NULL;
+	klass->start_drag = NULL;
 	
 	klass->add = NULL;
 	klass->add_array = NULL;
@@ -592,7 +624,7 @@ etg_class_init (GtkObjectClass *object_class)
 	klass->get_focus = etg_get_focus;
 	klass->get_printable = NULL;
 	klass->compute_location = NULL;
-	klass->get_position = NULL;
+	klass->get_cell_geometry = NULL;
 
 	etg_parent_class = gtk_type_class (PARENT_TYPE);
 
@@ -644,6 +676,14 @@ etg_class_init (GtkObjectClass *object_class)
 				e_marshal_INT__INT_INT_POINTER,
 				GTK_TYPE_INT, 3, GTK_TYPE_INT, GTK_TYPE_INT, GTK_TYPE_GDK_EVENT);
 
+	etg_signals [START_DRAG] =
+		gtk_signal_new ("start_drag",
+				GTK_RUN_LAST,
+				object_class->type,
+				GTK_SIGNAL_OFFSET (ETableGroupClass, start_drag),
+				e_marshal_INT__INT_INT_POINTER,
+				GTK_TYPE_INT, 3, GTK_TYPE_INT, GTK_TYPE_INT, GTK_TYPE_GDK_EVENT);
+
 	gtk_object_class_add_signals (object_class, etg_signals, LAST_SIGNAL);
 }
 
